@@ -32,14 +32,13 @@
 #include "gdkprivate-directfb.h"
 #include "gdkscreen.h"
 #include "gdkdisplaymanager.h"
-#include "gdkalias.h"
 
 
 extern void _gdk_visual_init            (void);
 extern void _gdk_events_init            (void);
 extern void _gdk_input_init             (void);
 extern void _gdk_dnd_init               (void);
-extern void _gdk_windowing_window_init  (GdkScreen *screen);
+extern void _gdk_windowing_window_init  (void);
 extern void _gdk_windowing_image_init   (void);
 extern void _gdk_directfb_keyboard_init (void);
 
@@ -48,28 +47,27 @@ static gint       gdk_directfb_glyph_surface_cache = 8;
 
 
 const GOptionEntry _gdk_windowing_args[] =
-  {
-    { "disable-aa-fonts",0,0,G_OPTION_ARG_INT,&gdk_directfb_monochrome_fonts,NULL,NULL    },
-    { "argb-font",0,0, G_OPTION_ARG_INT, &gdk_directfb_argb_font,NULL,NULL},
-    { "transparent-unfocused",0,0, G_OPTION_ARG_INT, &gdk_directfb_apply_focus_opacity,NULL,NULL },
-    { "glyph-surface-cache",0,0,G_OPTION_ARG_INT,&gdk_directfb_glyph_surface_cache,NULL,NULL },
-    { "enable-color-keying",0,0,G_OPTION_ARG_INT,&gdk_directfb_enable_color_keying,NULL,NULL },
-    { NULL }
-  };
+{
+  { "disable-aa-fonts",0,0,G_OPTION_ARG_INT,&gdk_directfb_monochrome_fonts,NULL,NULL    },
+  { "argb-font",0,0, G_OPTION_ARG_INT, &gdk_directfb_argb_font,NULL,NULL},
+  { "transparent-unfocused",0,0, G_OPTION_ARG_INT, &gdk_directfb_apply_focus_opacity,NULL,NULL },
+  { "glyph-surface-cache",0,0,G_OPTION_ARG_INT,&gdk_directfb_glyph_surface_cache,NULL,NULL },
+  { "enable-color-keying",0,0,G_OPTION_ARG_INT,&gdk_directfb_enable_color_keying,NULL,NULL },
+  { NULL}
+};
 
 /* Main entry point for gdk in 2.6 args are parsed
  */
-GdkDisplay *
-gdk_display_open (const gchar *display_name)
+GdkDisplay * gdk_display_open (const gchar *display_name)
 {
-  IDirectFB             *directfb;
-  IDirectFBDisplayLayer *layer;
-  IDirectFBInputDevice  *keyboard;
-  DFBResult              ret;
+  IDirectFB              *directfb;
+  IDirectFBDisplayLayer  *layer;
+  IDirectFBInputDevice   *keyboard;
+  DFBResult               ret;
 
   if (_gdk_display)
     {
-      return GDK_DISPLAY_OBJECT (_gdk_display); /* single display only */
+      return GDK_DISPLAY_OBJECT(_gdk_display); /* single display only */
     }
 
   ret = DirectFBInit (NULL, NULL);
@@ -108,19 +106,18 @@ gdk_display_open (const gchar *display_name)
       return NULL;
     }
 
-  _gdk_display->layer    = layer;
-  _gdk_display->keyboard = keyboard;
+  _gdk_display->layer=layer;
+  _gdk_display->keyboard=keyboard;
 
   _gdk_directfb_keyboard_init ();
 
   _gdk_screen = g_object_new (GDK_TYPE_SCREEN, NULL);
 
   _gdk_visual_init ();
-  _gdk_windowing_window_init (_gdk_screen);
+  _gdk_windowing_window_init ();
 
   gdk_screen_set_default_colormap (_gdk_screen,
-                                   gdk_screen_get_system_colormap (_gdk_screen));
-  _gdk_windowing_image_init ();
+                                   gdk_screen_get_system_colormap (_gdk_screen));  _gdk_windowing_image_init ();
 
   _gdk_events_init ();
   _gdk_input_init ();
@@ -131,7 +128,7 @@ gdk_display_open (const gchar *display_name)
   g_signal_emit_by_name (gdk_display_manager_get (),
 			 "display_opened", _gdk_display);
 
-  return GDK_DISPLAY_OBJECT (_gdk_display);
+  return GDK_DISPLAY_OBJECT(_gdk_display);
 }
 
 GType
@@ -162,23 +159,21 @@ gdk_display_dfb_get_type (void)
   return object_type;
 }
 
-IDirectFBSurface *
-gdk_display_dfb_create_surface (GdkDisplayDFB *display, int format, int width, int height)
-{
-  DFBResult              ret;
-  IDirectFBSurface      *temp;
-  DFBSurfaceDescription  dsc;
-  dsc.flags       = DSDESC_WIDTH | DSDESC_HEIGHT | DSDESC_PIXELFORMAT;
-  dsc.width       = width;
-  dsc.height      = height;
-  dsc.pixelformat = format;
-  ret             = display->directfb->CreateSurface (display->directfb, &dsc, &temp);
-  if (ret)
-    {
-      DirectFBError ("gdk_display_dfb_create_surface ", ret);
-      return NULL;
-    }
-  return temp;
+IDirectFBSurface * gdk_display_dfb_create_surface (GdkDisplayDFB *display,int format,int width, int height) { 
+	DFBResult              ret;
+	IDirectFBSurface      *temp;
+	DFBSurfaceDescription  dsc;
+	dsc.flags = DSDESC_WIDTH | DSDESC_HEIGHT | DSDESC_PIXELFORMAT;
+      	dsc.width       = width;
+      	dsc.height      = height;
+      	dsc.pixelformat = format;
+	ret = display->directfb->CreateSurface (display->directfb, &dsc, &temp);
+        if (ret)
+        {
+          DirectFBError ("gdk_display_dfb_create_surface ", ret);
+          return NULL;
+        }
+	return temp;
 
 }
 
@@ -190,7 +185,7 @@ gdk_display_dfb_create_surface (GdkDisplayDFB *display, int format, int width, i
 void
 _gdk_windowing_set_default_display (GdkDisplay *display)
 {
-  _gdk_display = GDK_DISPLAY_DFB (display);
+	_gdk_display=GDK_DISPLAY_DFB(display);
 }
 
 G_CONST_RETURN gchar *
@@ -221,13 +216,13 @@ gdk_display_get_default_screen (GdkDisplay *display)
 gboolean
 gdk_display_supports_shapes (GdkDisplay *display)
 {
-  return FALSE;
+       return FALSE;
 }
 
 gboolean
 gdk_display_supports_input_shapes (GdkDisplay *display)
 {
-  return FALSE;
+       return FALSE;
 }
 
 
@@ -245,22 +240,23 @@ GdkWindow *gdk_display_get_default_group (GdkDisplay *display)
 gboolean
 gdk_display_supports_selection_notification (GdkDisplay *display)
 {
-  return FALSE;
+	return FALSE;
 }
 
 gboolean gdk_display_request_selection_notification  (GdkDisplay *display,
                                                       GdkAtom     selection)
 
 {
-  g_warning("gdk_display_request_selection_notification Unimplemented function \n");
-  return FALSE;
+
+	g_warning("gdk_display_request_selection_notification Unimplemented function \n");
+	return FALSE;
 }
 
 gboolean
 gdk_display_supports_clipboard_persistence (GdkDisplay *display)
 {
-  g_warning("gdk_display_supports_clipboard_persistence Unimplemented function \n");
-  return FALSE;
+	g_warning("gdk_display_supports_clipboard_persistence Unimplemented function \n");
+	return FALSE;
 }
 
 void
@@ -271,7 +267,7 @@ gdk_display_store_clipboard (GdkDisplay    *display,
                              gint           n_targets)
 {
 
-  g_warning("gdk_display_store_clipboard Unimplemented function \n");
+	g_warning("gdk_display_store_clipboard Unimplemented function \n");
 
 }
 
@@ -293,7 +289,6 @@ gdk_directfb_pointer_grab (GdkWindow    *window,
 {
   GdkWindow             *toplevel;
   GdkWindowImplDirectFB *impl;
-
   if (_gdk_directfb_pointer_grab_window)
     {
       if (implicit_grab && !_gdk_directfb_pointer_implicit_grab)
@@ -518,10 +513,10 @@ gdk_notify_startup_complete (void)
  * gdk_notify_startup_complete_with_id:
  * @startup_id: a startup-notification identifier, for which notification
  *              process should be completed
- *
+ * 
  * Indicates to the GUI environment that the application has finished
  * loading, using a given identifier.
- *
+ * 
  * GTK+ will call this function automatically for #GtkWindow with custom
  * startup-notification identifier unless
  * gtk_window_set_auto_startup_notification() is called to disable
@@ -542,10 +537,5 @@ gdk_notify_startup_complete_with_id (const gchar* startup_id)
 gboolean
 gdk_display_supports_composite (GdkDisplay *display)
 {
-  return FALSE;
+    return FALSE;
 }
-
-
-#define __GDK_DISPLAY_X11_C__
-#include "gdkaliasdef.c"
-
