@@ -53,7 +53,6 @@
 #include "gdkinput-directfb.h"
 
 #include "gdkintl.h"
-#include "gdkalias.h"
 
 
 void
@@ -63,17 +62,6 @@ _gdk_windowing_init (void)
    */
 }
 
-void
-gdk_set_use_xshm (gboolean use_xshm)
-{
-}
-
-gboolean
-gdk_get_use_xshm (void)
-{
-  return FALSE;
-}
-
 void
 _gdk_windowing_display_set_sm_client_id (GdkDisplay *display,const gchar *sm_client_id)
 {
@@ -416,15 +404,14 @@ _gdk_windowing_pointer_grab (GdkWindow    *window,
   g_return_val_if_fail (GDK_IS_WINDOW (window), 0);
   g_return_val_if_fail (confine_to == NULL || GDK_IS_WINDOW (confine_to), 0);
 
-  _gdk_display_add_pointer_grab (_gdk_display,
+  _gdk_display_add_pointer_grab (&_gdk_display->parent,
                                  window,
                                  native,
                                  owner_events,
                                  event_mask,
-                                 confine_to,
-                                 cursor,
-                                 time);
-}
+                                 0,
+                                 time,
+                                 FALSE);
 
-#define __GDK_MAIN_X11_C__
-#include "gdkaliasdef.c"
+  return GDK_GRAB_SUCCESS;
+}
