@@ -24,7 +24,6 @@
 #include "gdk.h"
 #include "gdkspawn.h"
 #include "gdkprivate.h"
-#include "gdkalias.h"
 
 
 gboolean
@@ -103,6 +102,3 @@ gdk_spawn_command_line_on_screen (GdkScreen    *screen,
 
   return retval;
 }
-
-#define __GDK_SPAWN_X11_C__
-#include "gdkaliasdef.c"
