@@ -24,7 +24,7 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
  */
 
-#if defined(GTK_DISABLE_SINGLE_INCLUDES) && !defined (__GDK_H_INSIDE__) && !defined (GDK_COMPILATION)
+#if !defined (__GDK_H_INSIDE__) && !defined (GDK_COMPILATION)
 #error "Only <gdk/gdk.h> can be included directly."
 #endif
 
@@ -139,29 +139,27 @@ typedef enum
 {
   GDK_GC_FOREGROUND    = 1 << 0,
   GDK_GC_BACKGROUND    = 1 << 1,
-  GDK_GC_FONT	       = 1 << 2,
-  GDK_GC_FUNCTION      = 1 << 3,
-  GDK_GC_FILL	       = 1 << 4,
-  GDK_GC_TILE	       = 1 << 5,
-  GDK_GC_STIPPLE       = 1 << 6,
-  GDK_GC_CLIP_MASK     = 1 << 7,
-  GDK_GC_SUBWINDOW     = 1 << 8,
-  GDK_GC_TS_X_ORIGIN   = 1 << 9,
-  GDK_GC_TS_Y_ORIGIN   = 1 << 10,
-  GDK_GC_CLIP_X_ORIGIN = 1 << 11,
-  GDK_GC_CLIP_Y_ORIGIN = 1 << 12,
-  GDK_GC_EXPOSURES     = 1 << 13,
-  GDK_GC_LINE_WIDTH    = 1 << 14,
-  GDK_GC_LINE_STYLE    = 1 << 15,
-  GDK_GC_CAP_STYLE     = 1 << 16,
-  GDK_GC_JOIN_STYLE    = 1 << 17
+  GDK_GC_FUNCTION      = 1 << 2,
+  GDK_GC_FILL	       = 1 << 3,
+  GDK_GC_TILE	       = 1 << 4,
+  GDK_GC_STIPPLE       = 1 << 5,
+  GDK_GC_CLIP_MASK     = 1 << 6,
+  GDK_GC_SUBWINDOW     = 1 << 7,
+  GDK_GC_TS_X_ORIGIN   = 1 << 8,
+  GDK_GC_TS_Y_ORIGIN   = 1 << 9,
+  GDK_GC_CLIP_X_ORIGIN = 1 << 10,
+  GDK_GC_CLIP_Y_ORIGIN = 1 << 11,
+  GDK_GC_EXPOSURES     = 1 << 12,
+  GDK_GC_LINE_WIDTH    = 1 << 13,
+  GDK_GC_LINE_STYLE    = 1 << 14,
+  GDK_GC_CAP_STYLE     = 1 << 15,
+  GDK_GC_JOIN_STYLE    = 1 << 16
 } GdkGCValuesMask;
 
 struct _GdkGCValues
 {
   GdkColor	    foreground;
   GdkColor	    background;
-  GdkFont	   *font;
   GdkFunction	    function;
   GdkFill	    fill;
   GdkPixmap	   *tile;
@@ -190,12 +188,12 @@ struct _GdkGC
 {
   GObject parent_instance;
 
-  gint clip_x_origin;
-  gint clip_y_origin;
-  gint ts_x_origin;
-  gint ts_y_origin;
+  gint GSEAL (clip_x_origin);
+  gint GSEAL (clip_y_origin);
+  gint GSEAL (ts_x_origin);
+  gint GSEAL (ts_y_origin);
 
-  GdkColormap *colormap;
+  GdkColormap *GSEAL (colormap);
 };
 
 struct _GdkGCClass 
@@ -226,11 +224,6 @@ GdkGC *gdk_gc_new_with_values	  (GdkDrawable	    *drawable,
 				   GdkGCValues	    *values,
 				   GdkGCValuesMask   values_mask);
 
-#ifndef GDK_DISABLE_DEPRECATED
-GdkGC *gdk_gc_ref		  (GdkGC	    *gc);
-void   gdk_gc_unref		  (GdkGC	    *gc);
-#endif
-
 void   gdk_gc_get_values	  (GdkGC	    *gc,
 				   GdkGCValues	    *values);
 void   gdk_gc_set_values          (GdkGC           *gc,
@@ -240,10 +233,6 @@ void   gdk_gc_set_foreground	  (GdkGC	    *gc,
 				   const GdkColor   *color);
 void   gdk_gc_set_background	  (GdkGC	    *gc,
 				   const GdkColor   *color);
-#ifndef GDK_DISABLE_DEPRECATED
-void   gdk_gc_set_font		  (GdkGC	    *gc,
-				   GdkFont	    *font);
-#endif /* GDK_DISABLE_DEPRECATED */
 void   gdk_gc_set_function	  (GdkGC	    *gc,
 				   GdkFunction	     function);
 void   gdk_gc_set_fill		  (GdkGC	    *gc,
@@ -263,7 +252,7 @@ void   gdk_gc_set_clip_mask	  (GdkGC	    *gc,
 void   gdk_gc_set_clip_rectangle  (GdkGC	    *gc,
 				   const GdkRectangle *rectangle);
 void   gdk_gc_set_clip_region	  (GdkGC	    *gc,
-				   const GdkRegion  *region);
+				   const cairo_region_t  *region);
 void   gdk_gc_set_subwindow	  (GdkGC	    *gc,
 				   GdkSubwindowMode  mode);
 void   gdk_gc_set_exposures	  (GdkGC	    *gc,
@@ -293,9 +282,6 @@ void         gdk_gc_set_rgb_bg_color (GdkGC          *gc,
 				      const GdkColor *color);
 GdkScreen *  gdk_gc_get_screen	     (GdkGC          *gc);
 
-#ifndef GDK_DISABLE_DEPRECATED
-#define gdk_gc_destroy                 g_object_unref
-#endif /* GDK_DISABLE_DEPRECATED */
 
 G_END_DECLS
 
