@@ -53,7 +53,6 @@ struct _GdkGCQuartz
 {
   GdkGC             parent_instance;
 
-  GdkFont          *font;
   GdkFunction       function;
   GdkSubwindowMode  subwindow_mode;
   gboolean          graphics_exposures;
@@ -95,6 +94,7 @@ struct _GdkCursorPrivate
 struct _GdkDragContextPrivate
 {
   id <NSDraggingInfo> dragging_info;
+  GdkDevice *device;
 };
 
 extern GdkDisplay *_gdk_display;
@@ -149,7 +149,8 @@ void       _gdk_quartz_window_nspoint_to_gdk_xy     (NSPoint    point,
                                                      gint      *y);
 GdkWindow *_gdk_quartz_window_find_child            (GdkWindow *window,
 						     gint       x,
-						     gint       y);
+						     gint       y,
+                                                     gboolean   get_toplevel);
 void       _gdk_quartz_window_attach_to_parent      (GdkWindow *window);
 void       _gdk_quartz_window_detach_from_parent    (GdkWindow *window);
 void       _gdk_quartz_window_did_become_main       (GdkWindow *window);
@@ -157,8 +158,8 @@ void       _gdk_quartz_window_did_resign_main       (GdkWindow *window);
 void       _gdk_quartz_window_debug_highlight       (GdkWindow *window,
                                                      gint       number);
 
-void       _gdk_quartz_window_set_needs_display_in_rect (GdkWindow    *window,
-                                                         GdkRectangle *rect);
+void       _gdk_quartz_window_set_needs_display_in_region (GdkWindow    *window,
+                                                           cairo_region_t    *region);
 
 void       _gdk_quartz_window_update_position           (GdkWindow    *window);
 
@@ -203,10 +204,10 @@ void        _gdk_quartz_window_scroll      (GdkWindow       *window,
                                             gint             dy);
 void        _gdk_quartz_window_queue_translation (GdkWindow *window,
 						  GdkGC     *gc,
-                                                  GdkRegion *area,
+                                                  cairo_region_t *area,
                                                   gint       dx,
                                                   gint       dy);
 gboolean    _gdk_quartz_window_queue_antiexpose  (GdkWindow *window,
-                                                  GdkRegion *area);
+                                                  cairo_region_t *area);
 
 #endif /* __GDK_PRIVATE_QUARTZ_H__ */
