@@ -32,7 +32,7 @@
 #include "gdkx.h"
 #include "gdkprivate-x11.h"
 #include "gdkscreen-x11.h"
-#include "gdkalias.h"
+
 
 typedef struct _GdkColormapPrivateX11  GdkColormapPrivateX11;
 
@@ -1301,6 +1301,3 @@ gdk_colormap_get_screen (GdkColormap *cmap)
 
   return  GDK_COLORMAP_PRIVATE_DATA (cmap)->screen;
 }
-
-#define __GDK_COLOR_X11_C__
-#include "gdkaliasdef.c"
