@@ -24,7 +24,7 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
  */
 
-#include <config.h>
+#include "config.h"
 
 #include <stdlib.h>
 #include <sys/types.h>
@@ -54,7 +54,7 @@
 #include "gdkprivate-x11.h"
 #include "gdkdisplay-x11.h"
 #include "gdkscreen-x11.h"
-#include "gdkalias.h"
+
 
 typedef struct _GdkImagePrivateX11     GdkImagePrivateX11;
 
@@ -67,47 +67,20 @@ struct _GdkImagePrivateX11
 };
 
 static GList *image_list = NULL;
-static gpointer parent_class = NULL;
 
 static void gdk_x11_image_destroy (GdkImage      *image);
-static void gdk_image_init        (GdkImage      *image);
-static void gdk_image_class_init  (GdkImageClass *klass);
 static void gdk_image_finalize    (GObject       *object);
 
 #define PRIVATE_DATA(image) ((GdkImagePrivateX11 *) GDK_IMAGE (image)->windowing_data)
 
-GType
-gdk_image_get_type (void)
-{
-  static GType object_type = 0;
-
-  if (!object_type)
-    {
-      static const GTypeInfo object_info =
-      {
-        sizeof (GdkImageClass),
-        (GBaseInitFunc) NULL,
-        (GBaseFinalizeFunc) NULL,
-        (GClassInitFunc) gdk_image_class_init,
-        NULL,           /* class_finalize */
-        NULL,           /* class_data */
-        sizeof (GdkImage),
-        0,              /* n_preallocs */
-        (GInstanceInitFunc) gdk_image_init,
-      };
-      
-      object_type = g_type_register_static (G_TYPE_OBJECT,
-                                            "GdkImage",
-                                            &object_info, 0);
-    }
-  
-  return object_type;
-}
+G_DEFINE_TYPE (GdkImage, gdk_image, G_TYPE_OBJECT)
 
 static void
 gdk_image_init (GdkImage *image)
 {
-  image->windowing_data = g_new0 (GdkImagePrivateX11, 1);
+  image->windowing_data = G_TYPE_INSTANCE_GET_PRIVATE (image, 
+						       GDK_TYPE_IMAGE, 
+						       GdkImagePrivateX11);
 }
 
 static void
@@ -115,9 +88,9 @@ gdk_image_class_init (GdkImageClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-  parent_class = g_type_class_peek_parent (klass);
-
   object_class->finalize = gdk_image_finalize;
+
+  g_type_class_add_private (object_class, sizeof (GdkImagePrivateX11));
 }
 
 static void
@@ -127,7 +100,7 @@ gdk_image_finalize (GObject *object)
 
   gdk_x11_image_destroy (image);
   
-  G_OBJECT_CLASS (parent_class)->finalize (object);
+  G_OBJECT_CLASS (gdk_image_parent_class)->finalize (object);
 }
 
 
@@ -143,60 +116,6 @@ _gdk_image_exit (void)
     }
 }
 
-/**
- * gdk_image_new_bitmap:
- * @visual: the #GdkVisual to use for the image.
- * @data: the pixel data. 
- * @width: the width of the image in pixels. 
- * @height: the height of the image in pixels. 
- * 
- * Creates a new #GdkImage with a depth of 1 from the given data.
- * <warning><para>THIS FUNCTION IS INCREDIBLY BROKEN. The passed-in data must 
- * be allocated by malloc() (NOT g_malloc()) and will be freed when the 
- * image is freed.</para></warning>
- * 
- * Return value: a new #GdkImage.
- **/
-GdkImage *
-gdk_image_new_bitmap (GdkVisual *visual, gpointer data, gint width, gint height)
-{
-  Visual *xvisual;
-  GdkImage *image;
-  GdkDisplay *display;
-  GdkImagePrivateX11 *private;
-  
-  image = g_object_new (gdk_image_get_type (), NULL);
-  private = PRIVATE_DATA (image);
-  private->screen = gdk_visual_get_screen (visual);
-  display = GDK_SCREEN_DISPLAY (private->screen);
-  
-  image->type = GDK_IMAGE_NORMAL;
-  image->visual = visual;
-  image->width = width;
-  image->height = height;
-  image->depth = 1;
-  image->bits_per_pixel = 1;
-  if (display->closed)
-    private->ximage = NULL;
-  else
-    {
-      xvisual = ((GdkVisualPrivate*) visual)->xvisual;
-      private->ximage = XCreateImage (GDK_SCREEN_XDISPLAY (private->screen),
-				      xvisual, 1, XYBitmap,
-				      0, NULL, width, height, 8, 0);
-      private->ximage->data = data;
-      private->ximage->bitmap_bit_order = MSBFirst;
-      private->ximage->byte_order = MSBFirst;
-    }
-  
-  image->byte_order = MSBFirst;
-  image->mem =  private->ximage->data;
-  image->bpl = private->ximage->bytes_per_line;
-  image->bpp = 1;
-
-  return image;
-} 
-
 void
 _gdk_windowing_image_init (GdkDisplay *display)
 {
@@ -727,12 +646,6 @@ gdk_x11_image_destroy (GdkImage *image)
 
   private = PRIVATE_DATA (image);
 
-  if (private == NULL) /* This means that _gdk_image_exit() destroyed the
-                        * image already, and now we're called a second
-                        * time from _finalize()
-                        */
-    return;
-
   if (private->ximage)		/* Deal with failure of creation */
     {
       switch (image->type)
@@ -771,10 +684,9 @@ gdk_x11_image_destroy (GdkImage *image)
 	case GDK_IMAGE_FASTEST:
 	  g_assert_not_reached ();
 	}
+      
+      private->ximage = NULL;
     }
-
-  g_free (private);
-  image->windowing_data = NULL;
 }
 
 /**
@@ -840,7 +752,3 @@ _gdk_windowing_get_bits_for_depth (GdkDisplay *display,
   g_assert_not_reached ();
   return -1;
 }
-
-
-#define __GDK_IMAGE_X11_C__
-#include "gdkaliasdef.c"
