@@ -29,9 +29,26 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
  */
 
+/**
+ * SECTION:gtkaspectframe
+ * @Short_description: A frame that constrains its child to a particular aspect ratio
+ * @Title: GtkAspectFrame
+ *
+ * The #GtkAspectFrame is useful when you want
+ * pack a widget so that it can resize but always retains
+ * the same aspect ratio. For instance, one might be
+ * drawing a small preview of a larger image. #GtkAspectFrame
+ * derives from #GtkFrame, so it can draw a label and
+ * a frame around the child. The frame will be
+ * "shrink-wrapped" to the size of the child.
+ */
+
+#include "config.h"
 #include "gtkaspectframe.h"
+#include "gtkprivate.h"
 #include "gtkintl.h"
 
+
 enum {
   PROP_0,
   PROP_XALIGN,
@@ -40,8 +57,6 @@ enum {
   PROP_OBEY_CHILD
 };
 
-static void gtk_aspect_frame_class_init               (GtkAspectFrameClass *klass);
-static void gtk_aspect_frame_init                     (GtkAspectFrame      *aspect_frame);
 static void gtk_aspect_frame_set_property (GObject         *object,
 					   guint            prop_id,
 					   const GValue    *value,
@@ -56,35 +71,7 @@ static void gtk_aspect_frame_compute_child_allocation (GtkFrame            *fram
 #define MAX_RATIO 10000.0
 #define MIN_RATIO 0.0001
 
-static GtkFrameClass *parent_class = NULL;
-
-GType
-gtk_aspect_frame_get_type (void)
-{
-  static GType aspect_frame_type = 0;
-  
-  if (!aspect_frame_type)
-    {
-      static const GTypeInfo aspect_frame_info =
-      {
-	sizeof (GtkAspectFrameClass),
-	NULL,		/* base_init */
-	NULL,		/* base_finalize */
-	(GClassInitFunc) gtk_aspect_frame_class_init,
-	NULL,		/* class_finalize */
-	NULL,		/* class_data */
-	sizeof (GtkAspectFrame),
-	0,		/* n_preallocs */
-	(GInstanceInitFunc) gtk_aspect_frame_init,
-      };
-      
-      aspect_frame_type =
-	g_type_register_static (GTK_TYPE_FRAME, "GtkAspectFrame",
-				&aspect_frame_info, 0);
-    }
-  
-  return aspect_frame_type;
-}
+G_DEFINE_TYPE (GtkAspectFrame, gtk_aspect_frame, GTK_TYPE_FRAME)
 
 static void
 gtk_aspect_frame_class_init (GtkAspectFrameClass *class)
@@ -92,8 +79,6 @@ gtk_aspect_frame_class_init (GtkAspectFrameClass *class)
   GObjectClass *gobject_class;
   GtkFrameClass *frame_class;
   
-  parent_class = g_type_class_peek_parent (class);
-
   gobject_class = (GObjectClass*) class;
   frame_class = (GtkFrameClass*) class;
   
@@ -105,31 +90,31 @@ gtk_aspect_frame_class_init (GtkAspectFrameClass *class)
   g_object_class_install_property (gobject_class,
                                    PROP_XALIGN,
                                    g_param_spec_float ("xalign",
-                                                       _("Horizontal Alignment"),
-                                                       _("X alignment of the child"),
+                                                       P_("Horizontal Alignment"),
+                                                       P_("X alignment of the child"),
                                                        0.0, 1.0, 0.5,
-                                                       G_PARAM_READABLE | G_PARAM_WRITABLE ));
+                                                       GTK_PARAM_READWRITE));
   g_object_class_install_property (gobject_class,
                                    PROP_YALIGN,
                                    g_param_spec_float ("yalign",
-                                                       _("Vertical Alignment"),
-                                                       _("Y alignment of the child"),
+                                                       P_("Vertical Alignment"),
+                                                       P_("Y alignment of the child"),
                                                        0.0, 1.0, 0.5,
-                                                       G_PARAM_READABLE | G_PARAM_WRITABLE ));
+                                                       GTK_PARAM_READWRITE));
   g_object_class_install_property (gobject_class,
                                    PROP_RATIO,
                                    g_param_spec_float ("ratio",
-                                                       _("Ratio"),
-                                                       _("Aspect ratio if obey_child is FALSE"),
-                                                       MIN_RATIO, MAX_RATIO, 0.5,
-                                                       G_PARAM_READABLE | G_PARAM_WRITABLE ));
+                                                       P_("Ratio"),
+                                                       P_("Aspect ratio if obey_child is FALSE"),
+                                                       MIN_RATIO, MAX_RATIO, 1.0,
+                                                       GTK_PARAM_READWRITE));
   g_object_class_install_property (gobject_class,
                                    PROP_OBEY_CHILD,
-                                   g_param_spec_boolean ("obey_child",
-                                                         _("Obey child"),
-                                                         _("Force aspect ratio to match that of the frame's child"),
+                                   g_param_spec_boolean ("obey-child",
+                                                         P_("Obey child"),
+                                                         P_("Force aspect ratio to match that of the frame's child"),
                                                          TRUE,
-                                                         G_PARAM_READABLE | G_PARAM_WRITABLE));
+                                                         GTK_PARAM_READWRITE));
 }
 
 static void
@@ -214,6 +199,23 @@ gtk_aspect_frame_get_property (GObject         *object,
     }
 }
 
+/**
+ * gtk_aspect_frame_new:
+ * @label: Label text.
+ * @xalign: Horizontal alignment of the child within the allocation of
+ *  the #GtkAspectFrame. This ranges from 0.0 (left aligned)
+ *  to 1.0 (right aligned)
+ * @yalign: Vertical alignment of the child within the allocation of
+ *  the #GtkAspectFrame. This ranges from 0.0 (left aligned)
+ *  to 1.0 (right aligned)
+ * @ratio: The desired aspect ratio.
+ * @obey_child: If %TRUE, @ratio is ignored, and the aspect
+ *  ratio is taken from the requistion of the child.
+ *
+ * Create a new #GtkAspectFrame.
+ *
+ * Returns: the new #GtkAspectFrame.
+ */
 GtkWidget*
 gtk_aspect_frame_new (const gchar *label,
 		      gfloat       xalign,
@@ -235,6 +237,21 @@ gtk_aspect_frame_new (const gchar *label,
   return GTK_WIDGET (aspect_frame);
 }
 
+/**
+ * gtk_aspect_frame_set:
+ * @aspect_frame: a #GtkAspectFrame
+ * @xalign: Horizontal alignment of the child within the allocation of
+ *  the #GtkAspectFrame. This ranges from 0.0 (left aligned)
+ *  to 1.0 (right aligned)
+ * @yalign: Vertical alignment of the child within the allocation of
+ *  the #GtkAspectFrame. This ranges from 0.0 (left aligned)
+ *  to 1.0 (right aligned)
+ * @ratio: The desired aspect ratio.
+ * @obey_child: If %TRUE, @ratio is ignored, and the aspect
+ *  ratio is taken from the requistion of the child.
+ *
+ * Set parameters for an existing #GtkAspectFrame.
+ */
 void
 gtk_aspect_frame_set (GtkAspectFrame *aspect_frame,
 		      gfloat          xalign,
@@ -274,7 +291,7 @@ gtk_aspect_frame_set (GtkAspectFrame *aspect_frame,
       if (aspect_frame->obey_child != obey_child)
         {
           aspect_frame->obey_child = obey_child;
-          g_object_notify (G_OBJECT (aspect_frame), "obey_child");
+          g_object_notify (G_OBJECT (aspect_frame), "obey-child");
         }
       g_object_thaw_notify (G_OBJECT (aspect_frame));
 
@@ -290,7 +307,7 @@ gtk_aspect_frame_compute_child_allocation (GtkFrame      *frame,
   GtkBin *bin = GTK_BIN (frame);
   gdouble ratio;
 
-  if (bin->child && GTK_WIDGET_VISIBLE (bin->child))
+  if (bin->child && gtk_widget_get_visible (bin->child))
     {
       GtkAllocation full_allocation;
       
@@ -314,7 +331,7 @@ gtk_aspect_frame_compute_child_allocation (GtkFrame      *frame,
       else
 	ratio = aspect_frame->ratio;
 
-      parent_class->compute_child_allocation (frame, &full_allocation);
+      GTK_FRAME_CLASS (gtk_aspect_frame_parent_class)->compute_child_allocation (frame, &full_allocation);
       
       if (ratio * full_allocation.height > full_allocation.width)
 	{
@@ -331,5 +348,5 @@ gtk_aspect_frame_compute_child_allocation (GtkFrame      *frame,
       child_allocation->y = full_allocation.y + aspect_frame->yalign * (full_allocation.height - child_allocation->height);
     }
   else
-    parent_class->compute_child_allocation (frame, child_allocation);
+    GTK_FRAME_CLASS (gtk_aspect_frame_parent_class)->compute_child_allocation (frame, child_allocation);
 }
