@@ -24,8 +24,6 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
  */
 
-#undef GTK_DISABLE_DEPRECATED
-
 #include <stdlib.h>
 #include <string.h>
 #include "config.h"
@@ -42,7 +40,6 @@
 #include "gtkbindings.h"
 #include "gtkprivate.h"
 #include "gtkbuildable.h"
-#include "gtkalias.h"
 
 #define GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), GTK_TYPE_DIALOG, GtkDialogPrivate))
 
@@ -140,16 +137,14 @@ gtk_dialog_class_init (GtkDialogClass *class)
    * GtkDialog:has-separator:
    *
    * When %TRUE, the dialog has a separator bar above its buttons.
-   *
-   * Deprecated: 2.22: This property will be removed in GTK+ 3.
    */
   g_object_class_install_property (gobject_class,
                                    PROP_HAS_SEPARATOR,
                                    g_param_spec_boolean ("has-separator",
 							 P_("Has separator"),
 							 P_("The dialog has a separator bar above its buttons"),
-                                                         FALSE,
-                                                         GTK_PARAM_READWRITE | G_PARAM_DEPRECATED));
+                                                         TRUE,
+                                                         GTK_PARAM_READWRITE));
 
   /**
    * GtkDialog::response:
@@ -298,10 +293,12 @@ gtk_dialog_init (GtkDialog *dialog)
                     FALSE, TRUE, 0);
   gtk_widget_show (dialog->action_area);
 
-  dialog->separator = NULL;
+  dialog->separator = gtk_hseparator_new ();
+  gtk_box_pack_end (GTK_BOX (dialog->vbox), dialog->separator, FALSE, TRUE, 0);
+  gtk_widget_show (dialog->separator);
 
   gtk_window_set_type_hint (GTK_WINDOW (dialog),
-                            GDK_WINDOW_TYPE_HINT_DIALOG);
+			    GDK_WINDOW_TYPE_HINT_DIALOG);
   gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER_ON_PARENT);
 }
 
@@ -696,7 +693,7 @@ gtk_dialog_add_action_widget (GtkDialog *dialog,
  * appended to the end of the dialog's action area. The button widget is 
  * returned, but usually you don't need it.
  *
- * Return value: (transfer none): the button widget that was added
+ * Return value: the button widget that was added
  **/
 GtkWidget*
 gtk_dialog_add_button (GtkDialog   *dialog,
@@ -853,8 +850,7 @@ gtk_dialog_set_default_response (GtkDialog *dialog,
  * @setting: %TRUE to have a separator
  *
  * Sets whether the dialog has a separator above the buttons.
- *
- * Deprecated: 2.22: This function will be removed in GTK+ 3
+ * %TRUE by default.
  **/
 void
 gtk_dialog_set_has_separator (GtkDialog *dialog,
@@ -902,8 +898,6 @@ gtk_dialog_set_has_separator (GtkDialog *dialog,
  * Accessor for whether the dialog has a separator.
  * 
  * Return value: %TRUE if the dialog has a separator
- *
- * Deprecated: 2.22: This function will be removed in GTK+ 3
  **/
 gboolean
 gtk_dialog_get_has_separator (GtkDialog *dialog)
@@ -1132,7 +1126,7 @@ _gtk_dialog_set_ignore_separator (GtkDialog *dialog,
  * Gets the widget button that uses the given response ID in the action area
  * of a dialog.
  *
- * Returns: (transfer none):the @widget button that uses the given @response_id, or %NULL.
+ * Returns: the @widget button that uses the given @response_id, or %NULL.
  *
  * Since: 2.20
  */
@@ -1552,6 +1546,3 @@ gtk_dialog_get_content_area (GtkDialog *dialog)
 
   return dialog->vbox;
 }
-
-#define __GTK_DIALOG_C__
-#include "gtkaliasdef.c"
