@@ -25,7 +25,6 @@
 #include "gtktypebuiltins.h"
 #include "gtkprivate.h"
 #include "gtkmarshalers.h"
-#include "gtkalias.h"
 
 
 /**
@@ -44,7 +43,7 @@
  *
  * #GtkFileChooser allows for shortcuts to various places in the filesystem.
  * In the default implementation these are displayed in the left pane. It
- * may be a bit confusing at first taht these shortcuts come from various
+ * may be a bit confusing at first that these shortcuts come from various
  * sources and in various flavours, so lets explain the terminology here:
  * <variablelist>
  *    <varlistentry>
@@ -504,11 +503,7 @@
  * 	    </listitem>
  * 	  </varlistentry>
  * 	  <varlistentry>
-<<<<<<< HEAD
  * 	    <term><parameter>bookmark_indes</parameter>&nbsp;:</term>
-=======
- * 	    <term><parameter>bookmark_index</parameter>&nbsp;:</term>
->>>>>>> native-layout-incubator
  * 	    <listitem>
  * 	      <simpara>
  * 		index of the bookmark to switch to; the indices start at 0.
@@ -2759,6 +2754,3 @@ gtk_file_chooser_list_shortcut_folders (GtkFileChooser *chooser)
 }
 
 #endif
-
-#define __GTK_FILE_CHOOSER_C__
-#include "gtkaliasdef.c"
