@@ -53,7 +53,6 @@
 #include "gtkfilechooserbutton.h"
 
 #include "gtkprivate.h"
-#include "gtkalias.h"
 
 /* **************** *
  *  Private Macros  *
@@ -2890,6 +2889,3 @@ gtk_file_chooser_button_get_focus_on_click (GtkFileChooserButton *button)
   
   return button->priv->focus_on_click;
 }
-
-#define __GTK_FILE_CHOOSER_BUTTON_C__
-#include "gtkaliasdef.c"
