@@ -27,7 +27,6 @@
 #include "config.h"
 #include "gtkgc.h"
 #include "gtkintl.h"
-#include "gtkalias.h"
 
 
 typedef struct _GtkGCKey       GtkGCKey;
@@ -208,10 +207,6 @@ gtk_gc_key_hash (gpointer key)
     {
       hash_val += keyval->values.background.pixel;
     }
-  if (keyval->mask & GDK_GC_FONT)
-    {
-      hash_val += gdk_font_id (keyval->values.font);
-    }
   if (keyval->mask & GDK_GC_FUNCTION)
     {
       hash_val += (gint) keyval->values.function;
@@ -316,11 +311,6 @@ gtk_gc_key_equal (gpointer a,
       if (avalues->background.pixel != bvalues->background.pixel)
 	return FALSE;
     }
-  if (akey->mask & GDK_GC_FONT)
-    {
-      if (!gdk_font_equal (avalues->font, bvalues->font))
-	return FALSE;
-    }
   if (akey->mask & GDK_GC_FUNCTION)
     {
       if (avalues->function != bvalues->function)
@@ -412,6 +402,3 @@ gtk_gc_drawable_equal (GtkGCDrawable *a,
 {
   return (a->depth == b->depth);
 }
-
-#define __GTK_GC_C__
-#include "gtkaliasdef.c"
