@@ -17,7 +17,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#if defined(GTK_DISABLE_SINGLE_INCLUDES) && !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
 #error "Only <gtk/gtk.h> can be included directly."
 #endif
 
@@ -43,10 +43,30 @@ typedef struct _GtkIconView           GtkIconView;
 typedef struct _GtkIconViewClass      GtkIconViewClass;
 typedef struct _GtkIconViewPrivate    GtkIconViewPrivate;
 
+/**
+ * GtkIconViewForeachFunc:
+ * @icon_view: a #GtkIconView
+ * @path: The #GtkTreePath of a selected row
+ * @data: user data
+ *
+ * A function used by gtk_icon_view_selected_foreach() to map all
+ * selected rows.  It will be called on every selected row in the view.
+ */
 typedef void (* GtkIconViewForeachFunc)     (GtkIconView      *icon_view,
 					     GtkTreePath      *path,
 					     gpointer          data);
 
+/**
+ * GtkIconViewDropPosition:
+ * @GTK_ICON_VIEW_NO_DROP: no drop possible
+ * @GTK_ICON_VIEW_DROP_INTO: dropped item replaces the item
+ * @GTK_ICON_VIEW_DROP_LEFT: droppped item is inserted to the left
+ * @GTK_ICON_VIEW_DROP_RIGHT: dropped item is inserted to the right
+ * @GTK_ICON_VIEW_DROP_ABOVE: dropped item is inserted above
+ * @GTK_ICON_VIEW_DROP_BELOW: dropped item is inserted below
+ *
+ * An enum for determining where a dropped item goes.
+ */
 typedef enum
 {
   GTK_ICON_VIEW_NO_DROP,
@@ -125,6 +145,9 @@ gint           gtk_icon_view_get_column_spacing (GtkIconView    *icon_view);
 void           gtk_icon_view_set_margin        (GtkIconView    *icon_view, 
 					        gint            margin);
 gint           gtk_icon_view_get_margin        (GtkIconView    *icon_view);
+void           gtk_icon_view_set_item_padding  (GtkIconView    *icon_view, 
+					        gint            item_padding);
+gint           gtk_icon_view_get_item_padding  (GtkIconView    *icon_view);
 
 
 GtkTreePath *  gtk_icon_view_get_path_at_pos   (GtkIconView     *icon_view,
@@ -151,6 +174,10 @@ void             gtk_icon_view_unselect_path      (GtkIconView            *icon_
 						   GtkTreePath            *path);
 gboolean         gtk_icon_view_path_is_selected   (GtkIconView            *icon_view,
 						   GtkTreePath            *path);
+gint             gtk_icon_view_get_item_row       (GtkIconView            *icon_view,
+                                                   GtkTreePath            *path);
+gint             gtk_icon_view_get_item_column    (GtkIconView            *icon_view,
+                                                   GtkTreePath            *path);
 GList           *gtk_icon_view_get_selected_items (GtkIconView            *icon_view);
 void             gtk_icon_view_select_all         (GtkIconView            *icon_view);
 void             gtk_icon_view_unselect_all       (GtkIconView            *icon_view);
