@@ -36,7 +36,7 @@
 #include "gtkwindow.h"
 #include "gtkactivatable.h"
 #include "gtkprivate.h"
-#include "gtkalias.h"
+
 
 static void gtk_image_menu_item_destroy              (GtkObject        *object);
 static void gtk_image_menu_item_size_request         (GtkWidget        *widget,
@@ -326,7 +326,7 @@ gtk_image_menu_item_toggle_size_request (GtkMenuItem *menu_item,
 
   *requisition = 0;
 
-  if (image_menu_item->image && GTK_WIDGET_VISIBLE (image_menu_item->image))
+  if (image_menu_item->image && gtk_widget_get_visible (image_menu_item->image))
     {
       GtkRequisition image_requisition;
       guint toggle_spacing;
@@ -420,7 +420,7 @@ gtk_image_menu_item_size_request (GtkWidget      *widget,
 
   image_menu_item = GTK_IMAGE_MENU_ITEM (widget);
 
-  if (image_menu_item->image && GTK_WIDGET_VISIBLE (image_menu_item->image))
+  if (image_menu_item->image && gtk_widget_get_visible (image_menu_item->image))
     {
       GtkRequisition child_requisition;
       
@@ -464,7 +464,7 @@ gtk_image_menu_item_size_allocate (GtkWidget     *widget,
 
   GTK_WIDGET_CLASS (gtk_image_menu_item_parent_class)->size_allocate (widget, allocation);
 
-  if (image_menu_item->image && GTK_WIDGET_VISIBLE (image_menu_item->image))
+  if (image_menu_item->image && gtk_widget_get_visible (image_menu_item->image))
     {
       gint x, y, offset;
       GtkRequisition child_requisition;
@@ -726,8 +726,8 @@ gtk_image_menu_item_new_with_mnemonic (const gchar *label)
 /**
  * gtk_image_menu_item_new_from_stock:
  * @stock_id: the name of the stock item.
- * @accel_group: the #GtkAccelGroup to add the menu items accelerator to,
- *   or %NULL.
+ * @accel_group: (allow-none): the #GtkAccelGroup to add the menu items 
+ *   accelerator to, or %NULL.
  * @returns: a new #GtkImageMenuItem.
  *
  * Creates a new #GtkImageMenuItem containing the image and text from a 
@@ -977,12 +977,13 @@ gtk_image_menu_item_remove (GtkContainer *container,
     {
       gboolean widget_was_visible;
       
-      widget_was_visible = GTK_WIDGET_VISIBLE (child);
+      widget_was_visible = gtk_widget_get_visible (child);
       
       gtk_widget_unparent (child);
       image_menu_item->image = NULL;
       
-      if (GTK_WIDGET_VISIBLE (container) && widget_was_visible)
+      if (widget_was_visible &&
+          gtk_widget_get_visible (GTK_WIDGET (container)))
         gtk_widget_queue_resize (GTK_WIDGET (container));
 
       g_object_notify (G_OBJECT (image_menu_item), "image");
@@ -1057,6 +1058,3 @@ gtk_image_menu_item_screen_changed (GtkWidget *widget,
 
   show_image_change_notify (GTK_IMAGE_MENU_ITEM (widget));
 }
-
-#define __GTK_IMAGE_MENU_ITEM_C__
-#include "gtkaliasdef.c"
