@@ -29,7 +29,6 @@
 #include "gtkintl.h"
 #include "gtkbuildable.h"
 #include "gtkbuilderprivate.h"
-#include "gtkalias.h"
 
 #define GTK_LIST_STORE_IS_SORTED(list) (((GtkListStore*)(list))->sort_column_id != GTK_TREE_SORTABLE_UNSORTED_SORT_COLUMN_ID)
 #define VALID_ITER(iter, list_store) ((iter)!= NULL && (iter)->user_data != NULL && list_store->stamp == (iter)->stamp && !g_sequence_iter_is_end ((iter)->user_data) && g_sequence_iter_get_sequence ((iter)->user_data) == list_store->seq)
@@ -990,7 +989,7 @@ gtk_list_store_remove (GtkListStore *list_store,
 /**
  * gtk_list_store_insert:
  * @list_store: A #GtkListStore
- * @iter: An unset #GtkTreeIter to set to the new row
+ * @iter: (out): An unset #GtkTreeIter to set to the new row
  * @position: position to insert the new row
  *
  * Creates a new row at @position.  @iter will be changed to point to this new
@@ -1041,8 +1040,8 @@ gtk_list_store_insert (GtkListStore *list_store,
 /**
  * gtk_list_store_insert_before:
  * @list_store: A #GtkListStore
- * @iter: An unset #GtkTreeIter to set to the new row
- * @sibling: A valid #GtkTreeIter, or %NULL
+ * @iter: (out): An unset #GtkTreeIter to set to the new row
+ * @sibling: (allow-none): A valid #GtkTreeIter, or %NULL
  *
  * Inserts a new row before @sibling. If @sibling is %NULL, then the row will 
  * be appended to the end of the list. @iter will be changed to point to this 
@@ -1073,8 +1072,8 @@ gtk_list_store_insert_before (GtkListStore *list_store,
 /**
  * gtk_list_store_insert_after:
  * @list_store: A #GtkListStore
- * @iter: An unset #GtkTreeIter to set to the new row
- * @sibling: A valid #GtkTreeIter, or %NULL
+ * @iter: (out): An unset #GtkTreeIter to set to the new row
+ * @sibling: (allow-none): A valid #GtkTreeIter, or %NULL
  *
  * Inserts a new row after @sibling. If @sibling is %NULL, then the row will be
  * prepended to the beginning of the list. @iter will be changed to point to
@@ -1105,7 +1104,7 @@ gtk_list_store_insert_after (GtkListStore *list_store,
 /**
  * gtk_list_store_prepend:
  * @list_store: A #GtkListStore
- * @iter: An unset #GtkTreeIter to set to the prepend row
+ * @iter: (out): An unset #GtkTreeIter to set to the prepend row
  *
  * Prepends a new row to @list_store. @iter will be changed to point to this new
  * row. The row will be empty after this function is called. To fill in
@@ -1125,7 +1124,7 @@ gtk_list_store_prepend (GtkListStore *list_store,
 /**
  * gtk_list_store_append:
  * @list_store: A #GtkListStore
- * @iter: An unset #GtkTreeIter to set to the appended row
+ * @iter: (out): An unset #GtkTreeIter to set to the appended row
  *
  * Appends a new row to @list_store.  @iter will be changed to point to this new
  * row.  The row will be empty after this function is called.  To fill in
@@ -1883,7 +1882,7 @@ gtk_list_store_has_default_sort_func (GtkTreeSortable *sortable)
 /**
  * gtk_list_store_insert_with_values:
  * @list_store: A #GtkListStore
- * @iter: An unset #GtkTreeIter to set to the new row, or %NULL.
+ * @iter: (out) (allow-none): An unset #GtkTreeIter to set to the new row, or %NULL.
  * @position: position to insert the new row
  * @Varargs: pairs of column number and value, terminated with -1
  *
@@ -1969,7 +1968,7 @@ gtk_list_store_insert_with_values (GtkListStore *list_store,
 /**
  * gtk_list_store_insert_with_valuesv:
  * @list_store: A #GtkListStore
- * @iter: An unset #GtkTreeIter to set to the new row, or %NULL.
+ * @iter: (out) (allow-none): An unset #GtkTreeIter to set to the new row, or %NULL.
  * @position: position to insert the new row
  * @columns: an array of column numbers
  * @values: an array of GValues 
@@ -2382,6 +2381,3 @@ gtk_list_store_buildable_custom_tag_end (GtkBuildable *buildable,
   else
     g_warning ("Unknown custom list store tag: %s", tagname);
 }
-
-#define __GTK_LIST_STORE_C__
-#include "gtkaliasdef.c"
