@@ -42,7 +42,6 @@
 #include "gtkwindow.h"
 #include "gtkprivate.h"
 #include "gtkintl.h"
-#include "gtkalias.h"
 
 #define MENU_SHELL_TIMEOUT   500
 
@@ -135,6 +134,8 @@ struct _GtkMenuShellPrivate
   GtkMnemonicHash *mnemonic_hash;
   GtkKeyHash *key_hash;
 
+  GdkDevice *grab_pointer;
+
   guint take_focus : 1;
   guint activated_submenu : 1;
   /* This flag is a crutch to keep mnemonics in the same menu
@@ -548,7 +549,13 @@ _gtk_menu_shell_activate (GtkMenuShell *menu_shell)
 {
   if (!menu_shell->active)
     {
-      gtk_grab_add (GTK_WIDGET (menu_shell));
+      GdkDevice *device;
+
+      device = gtk_get_current_event_device ();
+
+      _gtk_menu_shell_set_grab_device (menu_shell, device);
+      gtk_device_grab_add (GTK_WIDGET (menu_shell), device, TRUE);
+
       menu_shell->have_grab = TRUE;
       menu_shell->active = TRUE;
     }
@@ -1073,6 +1080,8 @@ gtk_real_menu_shell_deactivate (GtkMenuShell *menu_shell)
 {
   if (menu_shell->active)
     {
+      GtkMenuShellPrivate *priv = GTK_MENU_SHELL_GET_PRIVATE (menu_shell);
+
       menu_shell->button = 0;
       menu_shell->active = FALSE;
       menu_shell->activate_time = 0;
@@ -1086,18 +1095,23 @@ gtk_real_menu_shell_deactivate (GtkMenuShell *menu_shell)
       if (menu_shell->have_grab)
 	{
 	  menu_shell->have_grab = FALSE;
-	  gtk_grab_remove (GTK_WIDGET (menu_shell));
+          gtk_device_grab_remove (GTK_WIDGET (menu_shell), priv->grab_pointer);
 	}
       if (menu_shell->have_xgrab)
 	{
-	  GdkDisplay *display = gtk_widget_get_display (GTK_WIDGET (menu_shell));
+          GdkDevice *keyboard;
 
-	  menu_shell->have_xgrab = FALSE;
-	  gdk_display_pointer_ungrab (display, GDK_CURRENT_TIME);
-	  gdk_display_keyboard_ungrab (display, GDK_CURRENT_TIME);
+          gdk_device_ungrab (priv->grab_pointer, GDK_CURRENT_TIME);
+          keyboard = gdk_device_get_associated_device (priv->grab_pointer);
+
+          if (keyboard)
+            gdk_device_ungrab (keyboard, GDK_CURRENT_TIME);
+
+          menu_shell->have_xgrab = FALSE;
 	}
 
       menu_shell->keyboard_mode = FALSE;
+      _gtk_menu_shell_set_grab_device (menu_shell, NULL);
 
       _gtk_menu_shell_update_mnemonics (menu_shell);
     }
@@ -1743,6 +1757,37 @@ _gtk_menu_shell_remove_mnemonic (GtkMenuShell *menu_shell,
   gtk_menu_shell_reset_key_hash (menu_shell);
 }
 
+void
+_gtk_menu_shell_set_grab_device (GtkMenuShell *menu_shell,
+                                 GdkDevice    *device)
+{
+  GtkMenuShellPrivate *priv;
+
+  g_return_if_fail (GTK_IS_MENU_SHELL (menu_shell));
+  g_return_if_fail (!device || GDK_IS_DEVICE (device));
+
+  priv = GTK_MENU_SHELL_GET_PRIVATE (menu_shell);
+
+  if (!device)
+    priv->grab_pointer = NULL;
+  else if (device->source == GDK_SOURCE_KEYBOARD)
+    priv->grab_pointer = gdk_device_get_associated_device (device);
+  else
+    priv->grab_pointer = device;
+}
+
+GdkDevice *
+_gtk_menu_shell_get_grab_device (GtkMenuShell  *menu_shell)
+{
+  GtkMenuShellPrivate *priv;
+
+  g_return_val_if_fail (GTK_IS_MENU_SHELL (menu_shell), FALSE);
+
+  priv = GTK_MENU_SHELL_GET_PRIVATE (menu_shell);
+
+  return priv->grab_pointer;
+}
+
 /**
  * gtk_menu_shell_get_take_focus:
  * @menu_shell: a #GtkMenuShell
@@ -1814,6 +1859,3 @@ gtk_menu_shell_set_take_focus (GtkMenuShell *menu_shell,
       g_object_notify (G_OBJECT (menu_shell), "take-focus");
     }
 }
-
-#define __GTK_MENU_SHELL_C__
-#include "gtkaliasdef.c"
