@@ -34,8 +34,6 @@
 #include "gtkprivate.h"
 #include "gtkplugprivate.h"
 
-#include "gtkalias.h"
-
 /**
  * SECTION:gtkplug
  * @Short_description: Toplevel for embedding into other processes
@@ -351,8 +349,7 @@ _gtk_plug_add_to_socket (GtkPlug   *plug,
 
   if (gtk_widget_get_realized (widget))
     {
-      w = gdk_window_get_width (widget->window);
-      h = gdk_window_get_height (widget->window);
+      gdk_drawable_get_size (GDK_DRAWABLE (widget->window), &w, &h);
       gdk_window_reparent (widget->window, plug->socket_window, -w, -h);
     }
 
@@ -1065,6 +1062,3 @@ _gtk_plug_focus_first_last (GtkPlug          *plug,
 
   gtk_widget_child_focus (GTK_WIDGET (plug), direction);
 }
-
-#define __GTK_PLUG_C__
-#include "gtkaliasdef.c"
