@@ -31,9 +31,7 @@
 #ifndef __GTK_PROGRESS_BAR_H__
 #define __GTK_PROGRESS_BAR_H__
 
-
-#include <gtk/gtkprogress.h>
-
+#include <gtk/gtkwidget.h>
 
 G_BEGIN_DECLS
 
@@ -48,12 +46,6 @@ G_BEGIN_DECLS
 typedef struct _GtkProgressBar       GtkProgressBar;
 typedef struct _GtkProgressBarClass  GtkProgressBarClass;
 
-typedef enum
-{
-  GTK_PROGRESS_CONTINUOUS,
-  GTK_PROGRESS_DISCRETE
-} GtkProgressBarStyle;
-
 typedef enum
 {
   GTK_PROGRESS_LEFT_TO_RIGHT,
@@ -64,9 +56,10 @@ typedef enum
 
 struct _GtkProgressBar
 {
-  GtkProgress progress;
+  GtkWidget parent;
+
+  GdkPixmap     *GSEAL (offscreen_pixmap);
 
-  GtkProgressBarStyle       GSEAL (bar_style);
   GtkProgressBarOrientation GSEAL (orientation);
 
   guint GSEAL (blocks);
@@ -81,50 +74,33 @@ struct _GtkProgressBar
   guint GSEAL (activity_dir) : 1;
   guint GSEAL (ellipsize) : 3;
   guint GSEAL (dirty) : 1;
+  guint GSEAL (activity_mode) : 1;
+  guint GSEAL (show_text) : 1;
 };
 
 struct _GtkProgressBarClass
 {
-  GtkProgressClass parent_class;
+  GtkWidgetClass parent_class;
+
+  void (* paint)            (GtkProgressBar *progress);
+  void (* update)           (GtkProgressBar *progress);
+  void (* act_mode_enter)   (GtkProgressBar *progress);
 
   /* Padding for future expansion */
   void (*_gtk_reserved1) (void);
   void (*_gtk_reserved2) (void);
   void (*_gtk_reserved3) (void);
   void (*_gtk_reserved4) (void);
+  void (*_gtk_reserved5) (void);
+  void (*_gtk_reserved6) (void);
+  void (*_gtk_reserved7) (void);
+  void (*_gtk_reserved8) (void);
 };
 
 
 GType      gtk_progress_bar_get_type             (void) G_GNUC_CONST;
 GtkWidget* gtk_progress_bar_new                  (void);
 
-/*
- * GtkProgress/GtkProgressBar had serious problems in GTK 1.2.
- *
- *  - Only 3 or 4 functions are really needed for 95% of progress
- *    interfaces; GtkProgress[Bar] had about 25 functions, and
- *    didn't even include these 3 or 4.
- *  - In activity mode, the API involves setting the adjustment
- *    to any random value, just to have the side effect of
- *    calling the progress bar update function - the adjustment
- *    is totally ignored in activity mode
- *  - You set the activity step as a pixel value, which means to
- *    set the activity step you basically need to connect to
- *    size_allocate
- *  - There are ctree_set_expander_style()-functions, to randomly
- *    change look-and-feel for no good reason
- *  - The split between GtkProgress and GtkProgressBar makes no sense
- *    to me whatsoever.
- *
- * This was a big wart on GTK and made people waste lots of time,
- * both learning and using the interface.
- *
- * So, I have added what I feel is the correct API, and marked all the
- * rest deprecated. However, the changes are 100% backward-compatible and
- * should break no existing code.
- *
- * The following 9 functions are the new programming interface.
- */
 void       gtk_progress_bar_pulse                (GtkProgressBar *pbar);
 void       gtk_progress_bar_set_text             (GtkProgressBar *pbar,
                                                   const gchar    *text);
@@ -134,7 +110,7 @@ void       gtk_progress_bar_set_fraction         (GtkProgressBar *pbar,
 void       gtk_progress_bar_set_pulse_step       (GtkProgressBar *pbar,
                                                   gdouble         fraction);
 void       gtk_progress_bar_set_orientation      (GtkProgressBar *pbar,
-						  GtkProgressBarOrientation orientation);
+                                                  GtkProgressBarOrientation orientation);
 
 G_CONST_RETURN gchar* gtk_progress_bar_get_text       (GtkProgressBar *pbar);
 gdouble               gtk_progress_bar_get_fraction   (GtkProgressBar *pbar);
@@ -142,9 +118,12 @@ gdouble               gtk_progress_bar_get_pulse_step (GtkProgressBar *pbar);
 
 GtkProgressBarOrientation gtk_progress_bar_get_orientation (GtkProgressBar *pbar);
 void               gtk_progress_bar_set_ellipsize (GtkProgressBar     *pbar,
-						   PangoEllipsizeMode  mode);
+                                                   PangoEllipsizeMode  mode);
 PangoEllipsizeMode gtk_progress_bar_get_ellipsize (GtkProgressBar     *pbar);
 
+void               gtk_progress_bar_set_show_text (GtkProgressBar     *pbar,
+                                                   gboolean            show_text);
+gboolean           gtk_progress_bar_get_show_text (GtkProgressBar     *pbar);
 
 G_END_DECLS
 
