@@ -21,6 +21,10 @@
  *      Mark McLoughlin <mark@skynet.ie>
  */
 
+#if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#error "Only <gtk/gtk.h> can be included directly."
+#endif
+
 #ifndef __GTK_STATUS_ICON_H__
 #define __GTK_STATUS_ICON_H__
 
@@ -44,26 +48,33 @@ struct _GtkStatusIcon
 {
   GObject               parent_instance;
 
-  GtkStatusIconPrivate *priv;
+  GtkStatusIconPrivate *GSEAL (priv);
 };
 
 struct _GtkStatusIconClass
 {
   GObjectClass parent_class;
 
-  void     (* activate)     (GtkStatusIcon *status_icon);
-  void     (* popup_menu)   (GtkStatusIcon *status_icon,
-			     guint          button,
-			     guint32        activate_time);
-  gboolean (* size_changed) (GtkStatusIcon *status_icon,
-			     gint           size);
+  void     (* activate)             (GtkStatusIcon  *status_icon);
+  void     (* popup_menu)           (GtkStatusIcon  *status_icon,
+                                     guint           button,
+                                     guint32         activate_time);
+  gboolean (* size_changed)         (GtkStatusIcon  *status_icon,
+                                     gint            size);
+  gboolean (* button_press_event)   (GtkStatusIcon  *status_icon,
+                                     GdkEventButton *event);
+  gboolean (* button_release_event) (GtkStatusIcon  *status_icon,
+                                     GdkEventButton *event);
+  gboolean (* scroll_event)         (GtkStatusIcon  *status_icon,
+                                     GdkEventScroll *event);
+  gboolean (* query_tooltip)        (GtkStatusIcon  *status_icon,
+                                     gint            x,
+                                     gint            y,
+                                     gboolean        keyboard_mode,
+                                     GtkTooltip     *tooltip);
 
   void (*__gtk_reserved1);
   void (*__gtk_reserved2);
-  void (*__gtk_reserved3);
-  void (*__gtk_reserved4);
-  void (*__gtk_reserved5);
-  void (*__gtk_reserved6);  
 };
 
 GType                 gtk_status_icon_get_type           (void) G_GNUC_CONST;
@@ -73,6 +84,7 @@ GtkStatusIcon        *gtk_status_icon_new_from_pixbuf    (GdkPixbuf          *pi
 GtkStatusIcon        *gtk_status_icon_new_from_file      (const gchar        *filename);
 GtkStatusIcon        *gtk_status_icon_new_from_stock     (const gchar        *stock_id);
 GtkStatusIcon        *gtk_status_icon_new_from_icon_name (const gchar        *icon_name);
+GtkStatusIcon        *gtk_status_icon_new_from_gicon     (GIcon              *icon);
 
 void                  gtk_status_icon_set_from_pixbuf    (GtkStatusIcon      *status_icon,
 							  GdkPixbuf          *pixbuf);
@@ -82,12 +94,15 @@ void                  gtk_status_icon_set_from_stock     (GtkStatusIcon      *st
 							  const gchar        *stock_id);
 void                  gtk_status_icon_set_from_icon_name (GtkStatusIcon      *status_icon,
 							  const gchar        *icon_name);
+void                  gtk_status_icon_set_from_gicon     (GtkStatusIcon      *status_icon,
+                                                          GIcon              *icon);
 
 GtkImageType          gtk_status_icon_get_storage_type   (GtkStatusIcon      *status_icon);
 
 GdkPixbuf            *gtk_status_icon_get_pixbuf         (GtkStatusIcon      *status_icon);
 G_CONST_RETURN gchar *gtk_status_icon_get_stock          (GtkStatusIcon      *status_icon);
 G_CONST_RETURN gchar *gtk_status_icon_get_icon_name      (GtkStatusIcon      *status_icon);
+GIcon                *gtk_status_icon_get_gicon          (GtkStatusIcon      *status_icon);
 
 gint                  gtk_status_icon_get_size           (GtkStatusIcon      *status_icon);
 
@@ -95,9 +110,17 @@ void                  gtk_status_icon_set_screen         (GtkStatusIcon      *st
                                                           GdkScreen          *screen);
 GdkScreen            *gtk_status_icon_get_screen         (GtkStatusIcon      *status_icon);
 
-void                  gtk_status_icon_set_tooltip        (GtkStatusIcon      *status_icon,
-							  const gchar        *tooltip_text);
-
+void                  gtk_status_icon_set_has_tooltip    (GtkStatusIcon      *status_icon,
+                                                          gboolean            has_tooltip);
+void                  gtk_status_icon_set_tooltip_text   (GtkStatusIcon      *status_icon,
+                                                          const gchar        *text);
+void                  gtk_status_icon_set_tooltip_markup (GtkStatusIcon      *status_icon,
+                                                          const gchar        *markup);
+void                  gtk_status_icon_set_title          (GtkStatusIcon      *status_icon,
+                                                          const gchar        *title);
+G_CONST_RETURN gchar *gtk_status_icon_get_title          (GtkStatusIcon      *status_icon);
+void                  gtk_status_icon_set_name           (GtkStatusIcon      *status_icon,
+                                                          const gchar        *name);
 void                  gtk_status_icon_set_visible        (GtkStatusIcon      *status_icon,
 							  gboolean            visible);
 gboolean              gtk_status_icon_get_visible        (GtkStatusIcon      *status_icon);
@@ -117,6 +140,11 @@ gboolean              gtk_status_icon_get_geometry       (GtkStatusIcon      *st
 							  GdkScreen         **screen,
 							  GdkRectangle       *area,
 							  GtkOrientation     *orientation);
+gboolean              gtk_status_icon_get_has_tooltip    (GtkStatusIcon      *status_icon);
+gchar                *gtk_status_icon_get_tooltip_text   (GtkStatusIcon      *status_icon);
+gchar                *gtk_status_icon_get_tooltip_markup (GtkStatusIcon      *status_icon);
+
+guint32               gtk_status_icon_get_x11_window_id  (GtkStatusIcon      *status_icon);
 
 G_END_DECLS
 
