@@ -30,7 +30,7 @@
 #include "gtktoggleaction.h"
 #include "gtkactivatable.h"
 #include "gtkprivate.h"
-#include "gtkalias.h"
+
 
 #define MENU_ID "gtk-toggle-tool-button-menu-id"
 
@@ -71,10 +71,10 @@ static void menu_item_activated (GtkWidget           *widget,
 
 
 static void gtk_toggle_tool_button_activatable_interface_init (GtkActivatableIface  *iface);
-static void gtk_toggle_tool_button_activatable_update         (GtkActivatable       *activatable,
+static void gtk_toggle_tool_button_update                     (GtkActivatable       *activatable,
 							       GtkAction            *action,
 							       const gchar          *property_name);
-static void gtk_toggle_tool_button_activatable_reset          (GtkActivatable       *activatable,
+static void gtk_toggle_tool_button_sync_action_properties     (GtkActivatable       *activatable,
 							       GtkAction            *action);
 
 static GtkActivatableIface *parent_activatable_iface;
@@ -311,18 +311,18 @@ button_toggled (GtkWidget           *widget,
     }
 }
 
-static void 
-gtk_toggle_tool_button_activatable_interface_init (GtkActivatableIface  *iface)
+static void
+gtk_toggle_tool_button_activatable_interface_init (GtkActivatableIface *iface)
 {
   parent_activatable_iface = g_type_interface_peek_parent (iface);
-  iface->update = gtk_toggle_tool_button_activatable_update;
-  iface->reset = gtk_toggle_tool_button_activatable_reset;
+  iface->update = gtk_toggle_tool_button_update;
+  iface->sync_action_properties = gtk_toggle_tool_button_sync_action_properties;
 }
 
 static void
-gtk_toggle_tool_button_activatable_update (GtkActivatable  *activatable,
-					   GtkAction       *action,
-					   const gchar     *property_name)
+gtk_toggle_tool_button_update (GtkActivatable *activatable,
+			       GtkAction      *action,
+			       const gchar    *property_name)
 {
   GtkToggleToolButton *button;
 
@@ -339,12 +339,12 @@ gtk_toggle_tool_button_activatable_update (GtkActivatable  *activatable,
 }
 
 static void
-gtk_toggle_tool_button_activatable_reset (GtkActivatable  *activatable,
-					  GtkAction       *action)
+gtk_toggle_tool_button_sync_action_properties (GtkActivatable *activatable,
+					       GtkAction      *action)
 {
   GtkToggleToolButton *button;
 
-  parent_activatable_iface->reset (activatable, action);
+  parent_activatable_iface->sync_action_properties (activatable, action);
 
   if (!GTK_IS_TOGGLE_ACTION (action))
     return;
@@ -446,6 +446,3 @@ gtk_toggle_tool_button_get_active (GtkToggleToolButton *button)
 
   return button->priv->active;
 }
-
-#define __GTK_TOGGLE_TOOL_BUTTON_C__
-#include "gtkaliasdef.c"
