@@ -29,7 +29,6 @@
 #include <string.h>
 #include "gtkprivate.h"
 #include "gtkintl.h"
-#include "gtkalias.h"
 
 #define ANIMATION_TIMEOUT        50
 #define ANIMATION_DURATION      (ANIMATION_TIMEOUT * 4)
@@ -1181,7 +1180,7 @@ gtk_tool_item_group_realize (GtkWidget *widget)
   widget->window = gdk_window_new (gtk_widget_get_parent_window (widget),
                                    &attributes, attributes_mask);
 
-  display = gdk_window_get_display (widget->window);
+  display = gdk_drawable_get_display (widget->window);
 
   if (gdk_display_supports_composite (display))
     gdk_window_set_composited (widget->window, TRUE);
@@ -1555,7 +1554,7 @@ gtk_tool_item_group_class_init (GtkToolItemGroupClass *cls)
   g_object_class_install_property (oclass, PROP_COLLAPSED,
                                    g_param_spec_boolean ("collapsed",
                                                          P_("Collapsed"),
-                                                         P_("Whether the group has been collapsed and items are hidden"),
+                                                         P_("Wether the group has been collapsed and items are hidden"),
                                                          DEFAULT_COLLAPSED,
                                                          GTK_PARAM_READWRITE));
 
@@ -2431,7 +2430,3 @@ _gtk_tool_item_group_palette_reconfigured (GtkToolItemGroup *group)
 
   gtk_tool_item_group_header_adjust_style (group);
 }
-
-
-#define __GTK_TOOL_ITEM_GROUP_C__
-#include "gtkaliasdef.c"
