@@ -9,6 +9,8 @@
 *tp++ = gdk_cursor_get_type();
 *tp++ = gdk_cursor_type_get_type();
 *tp++ = gdk_device_get_type();
+*tp++ = gdk_device_manager_get_type();
+*tp++ = gdk_device_type_get_type();
 *tp++ = gdk_display_get_type();
 *tp++ = gdk_display_manager_get_type();
 *tp++ = gdk_drag_action_get_type();
@@ -20,17 +22,15 @@
 *tp++ = gdk_event_type_get_type();
 *tp++ = gdk_extension_mode_get_type();
 *tp++ = gdk_fill_get_type();
-*tp++ = gdk_fill_rule_get_type();
 *tp++ = gdk_filter_return_get_type();
-*tp++ = gdk_font_get_type();
-*tp++ = gdk_font_type_get_type();
 *tp++ = gdk_function_get_type();
+*tp++ = gdk_gc_get_type();
 *tp++ = gdk_gc_values_mask_get_type();
+*tp++ = gdk_grab_ownership_get_type();
 *tp++ = gdk_grab_status_get_type();
 *tp++ = gdk_gravity_get_type();
 *tp++ = gdk_image_get_type();
 *tp++ = gdk_image_type_get_type();
-*tp++ = gdk_input_condition_get_type();
 *tp++ = gdk_input_mode_get_type();
 *tp++ = gdk_input_source_get_type();
 *tp++ = gdk_interp_type_get_type();
@@ -39,7 +39,6 @@
 *tp++ = gdk_line_style_get_type();
 *tp++ = gdk_modifier_type_get_type();
 *tp++ = gdk_notify_type_get_type();
-*tp++ = gdk_overlap_type_get_type();
 *tp++ = gdk_owner_change_get_type();
 *tp++ = gdk_pango_renderer_get_type();
 *tp++ = gdk_pixbuf_alpha_mode_get_type();
@@ -87,7 +86,7 @@
 *tp++ = gtk_adjustment_get_type();
 *tp++ = gtk_alignment_get_type();
 *tp++ = gtk_anchor_type_get_type();
-*tp++ = gtk_arg_flags_get_type();
+*tp++ = gtk_application_get_type();
 *tp++ = gtk_arrow_get_type();
 *tp++ = gtk_arrow_placement_get_type();
 *tp++ = gtk_arrow_type_get_type();
@@ -101,7 +100,6 @@
 *tp++ = gtk_buildable_get_type();
 *tp++ = gtk_builder_error_get_type();
 *tp++ = gtk_builder_get_type();
-*tp++ = gtk_button_action_get_type();
 *tp++ = gtk_button_box_get_type();
 *tp++ = gtk_button_box_style_get_type();
 *tp++ = gtk_button_get_type();
@@ -122,12 +120,10 @@
 *tp++ = gtk_cell_renderer_state_get_type();
 *tp++ = gtk_cell_renderer_text_get_type();
 *tp++ = gtk_cell_renderer_toggle_get_type();
-*tp++ = gtk_cell_type_get_type();
 *tp++ = gtk_cell_view_get_type();
 *tp++ = gtk_check_button_get_type();
 *tp++ = gtk_check_menu_item_get_type();
 *tp++ = gtk_clipboard_get_type();
-*tp++ = gtk_clist_drag_pos_get_type();
 *tp++ = gtk_color_button_get_type();
 *tp++ = gtk_color_selection_dialog_get_type();
 *tp++ = gtk_color_selection_get_type();
@@ -135,11 +131,6 @@
 *tp++ = gtk_combo_box_get_type();
 *tp++ = gtk_container_get_type();
 *tp++ = gtk_corner_type_get_type();
-*tp++ = gtk_ctree_expander_style_get_type();
-*tp++ = gtk_ctree_expansion_type_get_type();
-*tp++ = gtk_ctree_line_style_get_type();
-*tp++ = gtk_ctree_pos_get_type();
-*tp++ = gtk_curve_type_get_type();
 *tp++ = gtk_debug_flag_get_type();
 *tp++ = gtk_delete_type_get_type();
 *tp++ = gtk_dest_defaults_get_type();
@@ -206,7 +197,6 @@
 *tp++ = gtk_layout_get_type();
 *tp++ = gtk_link_button_get_type();
 *tp++ = gtk_list_store_get_type();
-*tp++ = gtk_match_type_get_type();
 *tp++ = gtk_menu_bar_get_type();
 *tp++ = gtk_menu_direction_type_get_type();
 *tp++ = gtk_menu_get_type();
@@ -239,7 +229,6 @@
 *tp++ = gtk_plug_get_type();
 *tp++ = gtk_policy_type_get_type();
 *tp++ = gtk_position_type_get_type();
-*tp++ = gtk_preview_type_get_type();
 *tp++ = gtk_print_context_get_type();
 *tp++ = gtk_print_duplex_get_type();
 *tp++ = gtk_print_error_get_type();
@@ -254,7 +243,6 @@
 *tp++ = gtk_private_flags_get_type();
 *tp++ = gtk_progress_bar_get_type();
 *tp++ = gtk_progress_bar_orientation_get_type();
-*tp++ = gtk_progress_bar_style_get_type();
 *tp++ = gtk_radio_action_get_type();
 *tp++ = gtk_radio_button_get_type();
 *tp++ = gtk_radio_menu_item_get_type();
@@ -294,10 +282,10 @@
 *tp++ = gtk_separator_tool_item_get_type();
 *tp++ = gtk_settings_get_type();
 *tp++ = gtk_shadow_type_get_type();
-*tp++ = gtk_side_type_get_type();
-*tp++ = gtk_signal_run_type_get_type();
 *tp++ = gtk_size_group_get_type();
 *tp++ = gtk_size_group_mode_get_type();
+*tp++ = gtk_size_request_get_type();
+*tp++ = gtk_size_request_mode_get_type();
 *tp++ = gtk_socket_get_type();
 *tp++ = gtk_sort_type_get_type();
 *tp++ = gtk_spin_button_get_type();
@@ -319,7 +307,6 @@
 *tp++ = gtk_text_buffer_target_info_get_type();
 *tp++ = gtk_text_child_anchor_get_type();
 *tp++ = gtk_text_direction_get_type();
-*tp++ = gtk_text_get_type();
 *tp++ = gtk_text_iter_get_type();
 *tp++ = gtk_text_mark_get_type();
 *tp++ = gtk_text_search_flags_get_type();
@@ -330,7 +317,6 @@
 *tp++ = gtk_toggle_action_get_type();
 *tp++ = gtk_toggle_button_get_type();
 *tp++ = gtk_toggle_tool_button_get_type();
-*tp++ = gtk_toolbar_child_type_get_type();
 *tp++ = gtk_toolbar_get_type();
 *tp++ = gtk_toolbar_space_style_get_type();
 *tp++ = gtk_toolbar_style_get_type();
@@ -343,8 +329,6 @@
 *tp++ = gtk_tooltip_get_type();
 *tp++ = gtk_tree_drag_dest_get_type();
 *tp++ = gtk_tree_drag_source_get_type();
-*tp++ = gtk_tree_get_type();
-*tp++ = gtk_tree_item_get_type();
 *tp++ = gtk_tree_iter_get_type();
 *tp++ = gtk_tree_model_filter_get_type();
 *tp++ = gtk_tree_model_flags_get_type();
@@ -360,7 +344,6 @@
 *tp++ = gtk_tree_view_drop_position_get_type();
 *tp++ = gtk_tree_view_get_type();
 *tp++ = gtk_tree_view_grid_lines_get_type();
-*tp++ = gtk_tree_view_mode_get_type();
 *tp++ = gtk_ui_manager_get_type();
 *tp++ = gtk_ui_manager_item_type_get_type();
 *tp++ = gtk_unit_get_type();
