@@ -47,7 +47,6 @@
 #include "gtkuimanager.h"
 #include "gtkwindow.h"
 #include "gtkprivate.h"
-#include "gtkalias.h"
 
 #undef DEBUG_UI_MANAGER
 
@@ -242,7 +241,7 @@ gtk_ui_manager_class_init (GtkUIManagerClass *klass)
    * @merge: a #GtkUIManager
    * @widget: the added widget
    *
-   * The add_widget signal is emitted for each generated menubar and toolbar.
+   * The ::add-widget signal is emitted for each generated menubar and toolbar.
    * It is not emitted for generated popup menus, which can be obtained by 
    * gtk_ui_manager_get_widget().
    *
@@ -262,7 +261,7 @@ gtk_ui_manager_class_init (GtkUIManagerClass *klass)
    * GtkUIManager::actions-changed:
    * @merge: a #GtkUIManager
    *
-   * The "actions-changed" signal is emitted whenever the set of actions
+   * The ::actions-changed signal is emitted whenever the set of actions
    * changes.
    *
    * Since: 2.4
@@ -282,7 +281,7 @@ gtk_ui_manager_class_init (GtkUIManagerClass *klass)
    * @action: the action
    * @proxy: the proxy
    *
-   * The connect_proxy signal is emitted after connecting a proxy to 
+   * The ::connect-proxy signal is emitted after connecting a proxy to
    * an action in the group. 
    *
    * This is intended for simple customizations for which a custom action
@@ -308,7 +307,7 @@ gtk_ui_manager_class_init (GtkUIManagerClass *klass)
    * @action: the action
    * @proxy: the proxy
    *
-   * The disconnect_proxy signal is emitted after disconnecting a proxy 
+   * The ::disconnect-proxy signal is emitted after disconnecting a proxy
    * from an action in the group. 
    *
    * Since: 2.4
@@ -329,7 +328,7 @@ gtk_ui_manager_class_init (GtkUIManagerClass *klass)
    * @uimanager: the ui manager
    * @action: the action
    *
-   * The pre_activate signal is emitted just before the @action
+   * The ::pre-activate signal is emitted just before the @action
    * is activated.
    *
    * This is intended for applications to get notification
@@ -352,7 +351,7 @@ gtk_ui_manager_class_init (GtkUIManagerClass *klass)
    * @uimanager: the ui manager
    * @action: the action
    *
-   * The post_activate signal is emitted just after the @action
+   * The ::post-activate signal is emitted just after the @action
    * is activated.
    *
    * This is intended for applications to get notification
@@ -2107,7 +2106,7 @@ find_toolbar_position (GNode      *node,
 
 /**
  * _gtk_menu_is_empty:
- * @menu: a #GtkMenu or %NULL
+ * @menu: (allow-none): a #GtkMenu or %NULL
  * 
  * Determines whether @menu is empty. A menu is considered empty if it
  * the only visible children are tearoff menu items or "filler" menu 
@@ -2133,7 +2132,7 @@ _gtk_menu_is_empty (GtkWidget *menu)
   cur = children;
   while (cur) 
     {
-      if (GTK_WIDGET_VISIBLE (cur->data))
+      if (gtk_widget_get_visible (cur->data))
 	{
 	  if (!GTK_IS_TEAROFF_MENU_ITEM (cur->data) &&
 	      !g_object_get_data (cur->data, "gtk-empty-menu-item"))
@@ -2214,7 +2213,7 @@ update_smart_separators (GtkWidget *proxy)
 		  break;
 		}
 	    }
-	  else if (GTK_WIDGET_VISIBLE (cur->data))
+	  else if (gtk_widget_get_visible (cur->data))
 	    {
 	      last = NULL;
 	      if (GTK_IS_TEAROFF_MENU_ITEM (cur->data) || cur->data == filler)
@@ -3076,6 +3075,3 @@ gtk_ui_manager_add_ui_from_file (GtkUIManager *self,
 }
 
 #endif
-
-#define __GTK_UI_MANAGER_C__
-#include "gtkaliasdef.c"
